Documentation
¶
Index ¶
- func GetAssertions() map[string]int
- func GetPIDAssertions() map[string][]PidAssertion
- func GetThermalConditions() map[string]int
- func SubscribeAssertionChanges(channel chan<- AssertionChange)
- func SubscribeAssertionChangesAndRun(channel chan<- AssertionChange)
- func SubscribeThermalChanges(channel chan<- bool)
- func SubscribeThermalChangesAndRun(channel chan<- bool)
- type AssertionChange
- type PidAssertion
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func GetAssertions ¶
GetAssertions returns a map of assertion keys to values
func GetPIDAssertions ¶
func GetPIDAssertions() map[string][]PidAssertion
GetPIDAssertions returns a map of assertion keys to procceses holding those assertions
func GetThermalConditions ¶
GetThermalConditions returns the current cpu limits
func SubscribeAssertionChanges ¶
func SubscribeAssertionChanges(channel chan<- AssertionChange)
SubscribeAssertionChanges returns, changes come through the supplied channel once dispatch_main or nsapplication is run
func SubscribeAssertionChangesAndRun ¶
func SubscribeAssertionChangesAndRun(channel chan<- AssertionChange)
SubscribeAssertionChangesAndRun does not return, changes come through the supplied channel
func SubscribeThermalChanges ¶
func SubscribeThermalChanges(channel chan<- bool)
SubscribeThermalChanges returns, changes come through the supplied channel once dispatch_main or nsapplication is run
func SubscribeThermalChangesAndRun ¶
func SubscribeThermalChangesAndRun(channel chan<- bool)
SubscribeThermalChangesAndRun does not return, changes come through the supplied channel
Types ¶
type AssertionChange ¶
type AssertionChange struct {
Action string
Type string
Pid PidAssertion
}
AssertionChange represents a process making a change to an assertion
type PidAssertion ¶
PidAssertion represents one process that has an assertion